@@ -9,7 +9,7 @@
    modify it under the terms of the GNU Library General Public License
    as published by the Free Software Foundation; either version 2 of
    the License, or (at your option) any later version.
-   
+
    The Gnome Library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
@@ -25,8 +25,10 @@
 
 #include <config.h>
 #include <glib.h>
+#include <glib/gstdio.h>
 
 #include <string.h>
+#include <strings.h>
 #include <stdio.h>
 #include <time.h>
 #include <string.h>
@@ -39,7 +41,6 @@
 #include "gnome-util.h"
 #include "gnome-config.h"
 
-
 #if !defined getc_unlocked && !defined HAVE_GETC_UNLOCKED
 # define getc_unlocked(fp) getc (fp)
 #endif
@@ -119,7 +120,7 @@ config_concat_dir_and_key (const char *dir, const char *key)
 		return g_strconcat (dir, key, NULL);
 }
 
-/* The `release_path' and `parsed_path' routines are inside the
+/* The `release_path' and `parse_path' routines are inside the
    following file.  It is in a separate file to allow the test-suite
    to get at it, without needing to export special symbols.
 
@@ -132,7 +133,7 @@ config_concat_dir_and_key (const char *dir, const char *key)
    static ParsedPath *parse_path (const char *path, gboolean priv); */
 #include "parse-path.cP"
 
-static void 
+static void
 free_keys (TKeys *p)
 {
 	if (!p)
@@ -143,7 +144,7 @@ free_keys (TKeys *p)
 	g_free (p);
 }
 
-static void 
+static void
 free_sections (TSecHeader *p)
 {
 	if (!p)
@@ -156,7 +157,7 @@ free_sections (TSecHeader *p)
 	g_free (p);
 }
 
-static void 
+static void
 free_profile (TProfile *p)
 {
 	if (!p)
@@ -169,20 +170,20 @@ free_profile (TProfile *p)
 	g_free (p);
 }
 
-static int 
+static int
 is_loaded (const char *filename, TSecHeader **section)
 {
 	TProfile *p = Base;
 	TProfile *lastp = NULL;
 	struct stat st;
-	
+
 	/*
 	 * if the last one we accessed was this one we don't want to
 	 * search
 	 */
 	if (Current && strcasecmp (filename, Current->filename) == 0){
 		if (Current->last_checked != time (NULL)){
-			if (stat (filename, &st) == -1)
+			if (g_stat (filename, &st) == -1)
 				st.st_mtime = 0;
 			if (Current->mtime != st.st_mtime) {
 				free_sections (Current->section);
@@ -198,7 +199,7 @@ is_loaded (const char *filename, TSecHeader **section)
 		*section = Current->section;
 		return 1;
 	}
-	
+
 	while (p){
 		/*search and destroy empty nodes*/
 		if (p->filename[0]=='\0') {
@@ -212,7 +213,7 @@ is_loaded (const char *filename, TSecHeader **section)
 			p = next;
 		} else if (strcasecmp (filename, p->filename) == 0){
 			if (p->last_checked != time (NULL)){
-				if (stat (filename, &st) == -1)
+				if (g_stat (filename, &st) == -1)
 					st.st_mtime = 0;
 				if (p->mtime != st.st_mtime) {
 					if(p == Current)
@@ -273,7 +274,7 @@ escape_string_and_dup (char *s)
 
 	if(!s)
 		return g_strdup("");
-	
+
 	while (*p){
 		len++;
 		if (*p == '\n' || *p == '\\' || *p == '\r' || *p == '\0')
@@ -313,17 +314,17 @@ load (const char *file)
 	char CharBuffer [STRSIZE];
 	char *next = "";		/* Not needed */
 	int c;
-	
-	if ((f = fopen (file, "r"))==NULL)
+
+	if ((f = g_fopen (file, "r"))==NULL)
 		return NULL;
-	
+
 	state = FirstBrace;
 	while ((c = getc_unlocked (f)) != EOF){
 		if (c == '\r')		/* Ignore Carriage Return */
 			continue;
-		
+
 		switch (state){
-			
+
 		case OnSecHeader:
 			if (c == ']' || overflow){
 				*next = '\0';
@@ -358,7 +359,7 @@ load (const char *file)
 
 			if (c == '[' && state != KeyDefOnKey){
 				TSecHeader *temp;
-		
+
 				temp = SecHeader;
 				SecHeader = (TSecHeader *) g_malloc (sizeof (TSecHeader));
 				SecHeader->link = temp;
@@ -370,16 +371,16 @@ load (const char *file)
 			/* On first pass, don't allow dangling keys */
 			if (state == FirstBrace)
 				break;
-	    
+
 			if ((c == ' ' && state != KeyDefOnKey) || c == '\t')
 				break;
-	    
+
 			if (c == '\n' || overflow) { /* Abort Definition */
 				next = CharBuffer;
 				state = KeyDef;
                                 break;
                         }
-	    
+
 			if (c == '=' || overflow){
 				TKeys *temp;
 
@@ -407,9 +408,9 @@ load (const char *file)
 			} else
 				*next++ = c;
 			break;
-	    
+
 		} /* switch */
-	
+
 	} /* while ((c = getc_unlocked (f)) != EOF) */
 	if (c == EOF && state == KeyValue){
 		*next = '\0';
@@ -419,11 +420,11 @@ load (const char *file)
 	return SecHeader;
 }
 
-static void 
+static void
 new_key (TSecHeader *section, const char *key_name, const char *value)
 {
 	TKeys *key;
-    
+
 	key = (TKeys *) g_malloc (sizeof (TKeys));
 	key->key_name = g_strdup (key_name);
 	key->value   = g_strdup (value);
@@ -436,7 +437,7 @@ access_config (access_type mode, const char *section_name,
 	       const char *key_name, const char *def, const char *filename,
 	       gboolean *def_used)
 {
-    
+
 	TProfile   *New;
 	TSecHeader *section;
 	TKeys      *key;
@@ -446,7 +447,7 @@ access_config (access_type mode, const char *section_name,
 	if (!is_loaded (filename, &section)){
 		struct stat st;
 		
-		if (stat (filename, &st) == -1)
+		if (g_stat (filename, &st) == -1)
 			st.st_mtime = 0;
 
 		New = (TProfile *) g_malloc (sizeof (TProfile));
@@ -461,7 +462,7 @@ access_config (access_type mode, const char *section_name,
 		section = New->section;
 		Current = New;
 	}
-    
+
 	/* Start search */
 	for (; section; section = section->link){
 		/*if section name empty or deleted or not the one we're
@@ -470,7 +471,7 @@ access_config (access_type mode, const char *section_name,
 		    !*section->section_name ||
 		    strcasecmp (section->section_name, section_name))
 			continue;
-		
+
 		for (key = section->keys; key; key = key->link){
 			if (strcasecmp (key->key_name, key_name))
 				continue;
@@ -489,7 +490,7 @@ access_config (access_type mode, const char *section_name,
 			return NULL;
 		}
 	}
-    
+
 	/* Non existent section */
 	if ((mode == SET) && def){
 		section = (TSecHeader *) g_malloc (sizeof (TSecHeader));
@@ -499,7 +500,7 @@ access_config (access_type mode, const char *section_name,
 		section->link = Current->section;
 		Current->section = section;
 		Current->written_to = TRUE;
-	} 
+	}
 	if (def_used)
 		*def_used = TRUE;
 	return def;
@@ -547,7 +548,7 @@ access_config_extended (access_type mode, const char *section_name,
  			       strcmp (cache_filename, rel_file) == 0 &&
  			       now - cache_time <= 2);
  		if (!cache_valid) {
- 			if (cache_filename) 
+ 			if (cache_filename)
 				g_free (cache_filename);
 
  			cache_filename = g_strdup (rel_file);
@@ -562,7 +563,7 @@ access_config_extended (access_type mode, const char *section_name,
 			     tmp, TRUE, NULL);
  			g_free (tmp);
  			cache_overrride_filename = filename ? g_strdup (filename) : NULL;
-			
+
  			if (cache_global_filename)
 				g_free (cache_global_filename);
 
@@ -594,7 +595,7 @@ access_config_extended (access_type mode, const char *section_name,
 					 filename, &internal_def);
 		g_free (filename);
 		if (!internal_def) {
-			if (def_used) 
+			if (def_used)
 				*def_used = FALSE;
 			return ret_val;
 		}
@@ -610,7 +611,7 @@ access_config_extended (access_type mode, const char *section_name,
 			return ret_val;
 		} else {
 			/* it doesn't -- use the default value */
-			if (def_used) 
+			if (def_used)
 				*def_used = TRUE;
 			return def;
 		}
@@ -618,12 +619,12 @@ access_config_extended (access_type mode, const char *section_name,
 	g_assert_not_reached ();
 
 	/* keep the compiler happy */
-	if (def_used) 
+	if (def_used)
 		*def_used = TRUE;
 	return def;
 }
 
-static void 
+static void
 dump_keys (FILE *profile, TKeys *p)
 {
 	if (!p)
@@ -636,7 +637,7 @@ dump_keys (FILE *profile, TKeys *p)
 	}
 }
 
-static void 
+static void
 dump_sections (FILE *profile, TSecHeader *p)
 {
 	if (!p)
@@ -655,32 +656,22 @@ dump_sections (FILE *profile, TSecHeader *p)
 static gint
 check_path(char *path, mode_t newmode)
 {
-	gchar *dirpath;
-	gchar *p, *cur;
-	GString *newpath;
+	gchar *dir, *root, *p, *cur;
+	GString *newpath = NULL;
 	struct stat s;
 
 	g_return_val_if_fail (path != NULL, FALSE);
 
-	if(strchr(path,'/')==NULL)
-		return FALSE;
-
-	dirpath = strcpy (g_alloca (strlen (path) + 1), path);
-	g_return_val_if_fail (dirpath != NULL, FALSE);
-
-	if (*dirpath == '\0')
-		return FALSE;
-
 	/*not absolute, we refuse to work*/
-	if (dirpath[0] != '/')
+	if (!g_path_is_absolute(path))
 		return FALSE;
 
-	p = strrchr(dirpath,'/');
-		*p='\0';
+	dir = g_path_get_dirname (path);
 
 	/*special case if directory exists, this is probably gonna happen
 	  a lot so we don't want to go though checking it part by part*/
-	if (stat(dirpath, &s) == 0) {
+	if (stat(dir, &s) == 0) {
+		g_free(dir);
 		/*check if a directory*/
 		if (!S_ISDIR(s.st_mode))
 			return FALSE;
@@ -689,59 +680,72 @@ check_path(char *path, mode_t newmode)
 	}
 
 
-	/*skip leading '/'*/
-	p = dirpath;
-	while(*p == '/')
-		p++;
+	p = (gchar *) g_path_skip_root(dir);
+	root = g_strndup(dir, p-dir);
 
 	cur = p;
-	newpath = g_string_new(NULL);
 	while ((p = cur)) {
-	       	cur = strchr (cur, '/');
+	       	cur = strchr (p, G_DIR_SEPARATOR);
+#ifdef G_OS_WIN32
+		{
+			gchar *cur2 = strchr (p, '/');
+			if (cur == NULL || (cur2 != NULL && cur2 < cur))
+				cur = cur2;
+		}
+#endif
 		if (cur) {
 			*cur = '\0';
 			cur++;
 		}
-		
-		newpath = g_string_append_c(newpath,'/');
+
+		if (newpath == NULL)
+			newpath = g_string_new(root);
+		else
+			newpath = g_string_append_c(newpath, G_DIR_SEPARATOR);
 		newpath = g_string_append(newpath,p);
 		if(stat(newpath->str,&s)==0) {
 			/*check if a directory*/
 			if(!S_ISDIR(s.st_mode)) {
 				g_string_free(newpath,TRUE);
+				g_free(root);
+				g_free(dir);
 				return FALSE;
 			}
 		} else {
 			/*we couldn't stat it .. let's try making the
 			  directory*/
-			if(mkdir(newpath->str,newmode)!=0) {
+			if(g_mkdir(newpath->str,newmode)!=0) {
 				/*error, return false*/
 				g_string_free(newpath,TRUE);
+				g_free(root);
+				g_free(dir);
 				return FALSE;
 			}
 		}
 	}
 
 	g_string_free(newpath,TRUE);
+	g_free(root);
+	g_free(dir);
 
 	return TRUE;
 }
 
 
 
-static gboolean 
+static gboolean
 dump_profile (TProfile *p, gboolean one_only)
 {
 	gboolean ret = TRUE;
 	FILE *profile;
-    
+
 	if (!p)
 		return ret;
 	if(!one_only) {
 		if(!dump_profile (p->link, FALSE))
 			ret = FALSE;
 	}
-	
+
 	/*
 	 * was this profile written to?, if not it's not necessary to dump
 	 * it to disk
@@ -761,7 +765,7 @@ dump_profile (TProfile *p, gboolean one_only)
 		if(p->to_be_deleted) {
 			/*remove the file and remove all it's ramaints
 			  from memory*/
-			unlink(p->filename);
+			g_unlink(p->filename);
 			/* this already must have been true */
 			/*p->section = 0;*/
 			p->filename [0] = '\0';
@@ -770,7 +774,7 @@ dump_profile (TProfile *p, gboolean one_only)
 			if(p==Current)
 				Current = NULL;
 		} else if (check_path(p->filename,0755) &&
-		    (profile = fopen (p->filename, "w")) != NULL){
+		    (profile = g_fopen (p->filename, "w")) != NULL){
 			dump_sections (profile, p->section);
 			fclose (profile);
 		} else {
@@ -778,7 +782,7 @@ dump_profile (TProfile *p, gboolean one_only)
 			ret = FALSE;
 		}
 	}
-	
+
 	/*mark this to not be dumped any more*/
 	p->written_to = FALSE;
 
@@ -797,7 +801,7 @@ dump_profile (TProfile *p, gboolean one_only)
  * Returns: %TRUE if everything went well. %FALSE if any file
  * could not be written to disk.
  */
-gboolean 
+gboolean
 gnome_config_sync (void)
 {
 	gboolean ret;
@@ -836,14 +840,14 @@ gnome_config_sync (void)
  * could not be written to for some reason.  %FALSE is only returned
  * when a write was actually attempted and failed.
  */
-gboolean 
+gboolean
 gnome_config_sync_file_ (char *path, gboolean priv)
 {
 	gboolean ret = TRUE;
 	TProfile *p;
 	ParsedPath *pp;
 	char *fake_path;
-	
+
 	if (!path)
 		return ret;
 
@@ -867,7 +871,7 @@ gnome_config_sync_file_ (char *path, gboolean priv)
 }
 
 /**
- * gnome_config_clean_file: 
+ * gnome_config_clean_file:
  * @path: A gnome-config path
  *
  * Cleans up the configuration file specified by @path from any
@@ -884,13 +888,13 @@ gnome_config_sync_file_ (char *path, gboolean priv)
  *
  * Changes will take place after gnome_config_sync() has been invoked.
  */
-void 
+void
 gnome_config_clean_file_ (const char *path, gboolean priv)
 {
 	TProfile *p;
 	ParsedPath *pp;
 	char *fake_path;
-	
+
 	if (!path)
 		return;
 
@@ -899,11 +903,11 @@ gnome_config_clean_file_ (const char *path, gboolean priv)
 	g_free (fake_path);
 
 	Current = NULL;
-	
+
 	for (p = Base; p; p = p->link){
 		if (strcmp (pp->file, p->filename) != 0)
 			continue;
-		
+
 		free_sections (p->section);
 		p->section = NULL;
 		p->written_to = TRUE;
@@ -915,7 +919,7 @@ gnome_config_clean_file_ (const char *path, gboolean priv)
 }
 
 /**
- * gnome_config_drop_file: 
+ * gnome_config_drop_file:
  * @path: A gnome-config path
  *
  * Releases any memory resources that were allocated from accessing
@@ -929,14 +933,14 @@ gnome_config_clean_file_ (const char *path, gboolean priv)
  * Releases any memory resources that were allocated from accessing the
  * private configuration file in @path.
  */
-void 
+void
 gnome_config_drop_file_ (const char *path, gboolean priv)
 {
 	TProfile *p;
 	TProfile *last;
 	ParsedPath *pp;
 	char *fake_path;
-	
+
 	if (!path)
 		return;
 
@@ -945,16 +949,16 @@ gnome_config_drop_file_ (const char *path, gboolean priv)
 	g_free (fake_path);
 
 	Current = NULL;
-	
+
 	for (last = NULL,p = Base; p; last = p, p = p->link){
 		if (strcmp (pp->file, p->filename) != 0)
 			continue;
-		
+
 		if(last)
 			last->link = p->link;
 		else
 			Base = p->link;
-		
+
 		free_sections (p->section);
 		g_free(p->filename);
 		g_free(p);
@@ -999,11 +1003,11 @@ gnome_config_init_iterator_ (const char *path, gboolean priv)
 	fake_path = config_concat_dir_and_key (path, "key");
 	pp = parse_path (fake_path, priv);
 	g_free (fake_path);
-	
+
 	if (!is_loaded (pp->file, &section)){
 		struct stat st;
 		
-		if (stat (pp->file, &st) == -1){
+		if (g_stat (pp->file, &st) == -1){
 			st.st_mtime = 0;
 		}
 
@@ -1068,11 +1072,11 @@ gnome_config_init_iterator_sections_ (const char *path, gboolean priv)
 	fake_path = config_concat_dir_and_key (path, "section/key");
 	pp = parse_path (fake_path, priv);
 	g_free (fake_path);
-	
+
 	if (!is_loaded (pp->file, &section)){
 		struct stat st;
 		
-		if (stat (pp->file, &st) == -1)
+		if (g_stat (pp->file, &st) == -1)
 			st.st_mtime = 0;
 
 		New = (TProfile *) g_malloc (sizeof (TProfile));
@@ -1118,13 +1122,13 @@ gnome_config_iterator_next (void *iterator_handle, char **key, char **value)
 	 * return NULL at times)
 	 */
 	if(!iterator_handle)
-		return NULL; 
+		return NULL;
 
 	if (key)
 		*key = NULL;
 	if (value)
 		*value = NULL;
-	
+
 	if (iter->type == 0){
 		TKeys *keys;
 		keys = iter->value;
@@ -1152,7 +1156,7 @@ gnome_config_iterator_next (void *iterator_handle, char **key, char **value)
 			return iter;
 		} else {
 			g_free (iter);
-			return NULL; 
+			return NULL;
 		}
 	}
 }
@@ -1173,22 +1177,22 @@ gnome_config_iterator_next (void *iterator_handle, char **key, char **value)
  * configuration information.  Changes will only take place after
  * gnome_config_sync() has been invoked.
  */
-void 
+void
 gnome_config_clean_section_ (const char *path, gboolean priv)
 {
 	TProfile   *New;
 	TSecHeader *section;
 	ParsedPath *pp;
 	char *fake_path;
-	
+
 	fake_path = config_concat_dir_and_key (path, "key");
 	pp = parse_path (fake_path, priv);
 	g_free (fake_path);
-	
+
 	if (!is_loaded (pp->file, &section)){
 		struct stat st;
 
-		if (stat (pp->file, &st) == -1)
+		if (g_stat (pp->file, &st) == -1)
 			st.st_mtime = 0;
 
 		New = (TProfile *) g_malloc (sizeof (TProfile));
@@ -1232,7 +1236,7 @@ gnome_config_clean_section_ (const char *path, gboolean priv)
  *
  * Changes will take place after gnome_config_sync() has been invoked.
  */
-void 
+void
 gnome_config_clean_key_ (const char *path, gboolean priv)
 	/* *section_name, char *file */
 {
@@ -1240,13 +1244,13 @@ gnome_config_clean_key_ (const char *path, gboolean priv)
 	TSecHeader *section;
 	TKeys *key;
 	ParsedPath *pp;
-	
+
 	pp = parse_path (path, priv);
-	
+
 	if (!is_loaded (pp->file, &section)){
 		struct stat st;
 		
-		if (stat (pp->file, &st) == -1)
+		if (g_stat (pp->file, &st) == -1)
 			st.st_mtime = 0;
 
 		New = (TProfile *) g_malloc (sizeof (TProfile));
@@ -1292,7 +1296,7 @@ gnome_config_clean_key_ (const char *path, gboolean priv)
  *
  * Returns: %TRUE if the section exists, %FALSE otherwise.
  */
-gboolean 
+gboolean
 gnome_config_has_section_ (const char *path, gboolean priv)
 	/* char *section_name, char *profile */
 {
@@ -1304,11 +1308,11 @@ gnome_config_has_section_ (const char *path, gboolean priv)
 	fake_path = config_concat_dir_and_key (path, "key");
 	pp = parse_path (fake_path,priv);
 	g_free (fake_path);
-	
+
 	if (!is_loaded (pp->file, &section)){
 		struct stat st;
 		
-		if (stat (pp->file, &st) == -1)
+		if (g_stat (pp->file, &st) == -1)
 			st.st_mtime = 0;
 
 		New = (TProfile *) g_malloc (sizeof (TProfile));
@@ -1340,7 +1344,7 @@ gnome_config_has_section_ (const char *path, gboolean priv)
  * gnome config. Any pending information that has not been
  * written to disk is discarded.
  */
-void 
+void
 gnome_config_drop_all (void)
 {
 	free_profile (Base);
@@ -1394,7 +1398,7 @@ gnome_config_get_int_with_default_ (const char *path, gboolean *def, gboolean pr
 	ParsedPath *pp;
 	const char *r;
 	int  v;
-	
+
 	pp = parse_path (path, priv);
 	/*is there a better way to check if an absolute path has been given?*/
 	if (!priv && pp->opath[0] != '=')
@@ -1462,7 +1466,7 @@ gnome_config_get_float_with_default_ (const char *path, gboolean *def, gboolean
 	ParsedPath *pp;
 	const char *r;
 	gdouble v;
-	
+
 	pp = parse_path (path, priv);
 	if (!priv && pp->opath[0] != '=')
 		r = access_config_extended (LOOKUP, pp->section, pp->key,
@@ -1494,7 +1498,7 @@ get_string_with_default_from_pp (ParsedPath *pp, gboolean *def, gboolean priv)
 {
 	const char *r;
 	char *ret = NULL;
-	
+
 	if (!priv && pp->opath[0] != '=')
 		r = access_config_extended (LOOKUP, pp->section, pp->key,
 					    pp->def, pp->path, def);
@@ -1585,17 +1589,19 @@ gnome_config_get_translated_string_with_default_ (const char *path,
 						  gboolean priv)
 {
 	ParsedPath *pp;
-	const GList *language_list;
+	const char * const *language_list;
 	gboolean local_def = FALSE;
+	int i;
 
 	char *value= NULL;
 
-	language_list = gnome_i18n_get_language_list ("LC_MESSAGES");
+	language_list = g_get_language_names ();
 
 	pp = parse_path (path, priv);
 
-	while (!value && language_list) {
-		const char *lang= language_list->data;
+	i = 0;
+	while (!value && language_list[i] != NULL) {
+		const char *lang = language_list[i];
 
 		value = get_string_with_default_from_pp_with_lang
 			(pp, lang, &local_def, priv);
@@ -1621,7 +1627,7 @@ gnome_config_get_translated_string_with_default_ (const char *path,
 				}
 			}
 		}
-		language_list = language_list->next;
+		i++;
 	}
 
 	if (def != NULL) {
@@ -1692,7 +1698,7 @@ gnome_config_get_string_with_default_ (const char *path, gboolean *def,
 {
 	ParsedPath *pp;
 	char *ret;
-	
+
 	pp = parse_path (path, priv);
 	ret = get_string_with_default_from_pp (pp, def, priv);
 	release_path (pp);
@@ -1745,7 +1751,7 @@ gnome_config_get_bool_with_default_ (const char *path, gboolean *def,
 	ParsedPath *pp;
 	const char *r;
 	int  v;
-	
+
 	pp = parse_path (path, priv);
 	if (!priv && pp->opath[0] != '=')
 		r = access_config_extended (LOOKUP, pp->section, pp->key,
@@ -1830,8 +1836,8 @@ gnome_config_make_vector (const char *string, int *argcp, char ***argvp)
 		(*argvp)[count++] = tmp = s;
 
 		while (*s) {
-			if (*s == '\\') 
-				s++;				
+			if (*s == '\\')
+				s++;
 			if (!*s) break;
 			*tmp++ = *s++;
 		}
@@ -1893,7 +1899,7 @@ gnome_config_get_vector_with_default_ (const char *path, int *argcp,
 {
 	ParsedPath *pp;
 	const char *rr;
-	
+
 	pp = parse_path (path, priv);
 	if (!priv && pp->opath[0] != '=')
 		rr = access_config_extended (LOOKUP, pp->section, pp->key,
@@ -1914,7 +1920,7 @@ gnome_config_get_vector_with_default_ (const char *path, int *argcp,
  * gnome_config_set_translated_string:
  * @path: A gnome configuration path to a key.
  * @value: A string value to set.
- * 
+ *
  * Stores the string value @value in the file/section/key defined
  * by the @path on the proper section for the current language set by
  * by the user.
@@ -1923,7 +1929,7 @@ gnome_config_get_vector_with_default_ (const char *path, int *argcp,
  * gnome_config_private_set_translated_string:
  * @path: A gnome configuration path to a key.
  * @new_value: A string value to set.
- * 
+ *
  * Stores the string value @new_value in the file/section/key defined by the
  * @path on the proper section for the current language set by by the user.
  * The configuration value is stored in the user's private storage area.
@@ -1932,13 +1938,12 @@ void
 gnome_config_set_translated_string_ (const char *path, const char *value,
 				     gboolean priv)
 {
-	const GList *language_list;
+	const char * const *language_list;
 	const char *lang;
 	char *tkey;
 
-	language_list = gnome_i18n_get_language_list("LC_MESSAGES");
-
-	lang= language_list ? language_list->data : NULL;
+	language_list = g_get_language_names ();
+	lang = language_list[0];
 
 	if (lang && (strcmp (lang, "C") != 0)) {
 		tkey = g_strconcat (path, "[", lang, "]", NULL);
@@ -1970,7 +1975,7 @@ gnome_config_set_string_ (const char *path, const char *new_value, gboolean priv
 {
 	ParsedPath *pp;
 	const char *r;
-	
+
 	pp = parse_path (path, priv);
 	r = access_config (SET, pp->section, pp->key, new_value, pp->file,
 			   NULL);
@@ -2000,7 +2005,7 @@ gnome_config_set_int_ (const char *path, int new_value, gboolean priv)
 	ParsedPath *pp;
 	char intbuf [40];
 	const char *r;
-	
+
 	pp = parse_path (path, priv);
 	g_snprintf (intbuf, sizeof(intbuf), "%d", new_value);
 	r = access_config (SET, pp->section, pp->key, intbuf, pp->file,
@@ -2031,7 +2036,7 @@ gnome_config_set_float_ (const char *path, gdouble new_value, gboolean priv)
 	ParsedPath *pp;
 	char floatbuf [40];
 	const char *r;
-	
+
 	pp = parse_path (path, priv);
 
         /* make sure we write values in a consistent manner */
@@ -2065,7 +2070,7 @@ gnome_config_set_bool_ (const char *path, gboolean new_value, gboolean priv)
 {
 	ParsedPath *pp;
 	const char *r;
-	
+
 	pp = parse_path (path, priv);
 	r = access_config (SET, pp->section, pp->key,
 			   new_value ? "true" : "false", pp->file, NULL);
@@ -2093,7 +2098,7 @@ gnome_config_assemble_vector (int argc, const char *const argv [])
 
 	/*
 	 * Compute length of quoted string.  We cheat and just use
-	 * twice the sum of the lengths of all the strings.  
+	 * twice the sum of the lengths of all the strings.
 	 */
 	len = 1;
 	for (i = 0; i < argc; ++i)
@@ -2157,7 +2162,7 @@ gnome_config_set_vector_ (const char *path, int argc,
  *
  * Library code will usually have to set the prefix before doing
  * any gnome-configuration access, since the application might
- * be using their own prefix. 
+ * be using their own prefix.
  */
 void
 gnome_config_push_prefix (const char *path)
@@ -2232,6 +2237,5 @@ main ()
 	x ("/file/seccion/llave", "USERDIR/file", "seccion", "llave", NULL);
 	x ("/file/archivo/archivo/seccion/llave", "USERDIR/file/archivo/archivo", "seccion", "llave", NULL);
 	x ("/file/archivo/archivo/seccion/llave=valor", "USERDIR/file/archivo/archivo", "seccion", "llave", "valor");
-	
 }
 #endif
