@@ -59,6 +59,8 @@
  *
  * Returns: %TRUE if everything went fine, %FALSE otherwise (in which case
  * @error will contain the actual error).
+ *
+ * Since: 2.2
  */
 gboolean
 gnome_url_show_with_env (const char  *url,
@@ -72,32 +74,32 @@ gnome_url_show_with_env (const char  *url,
 	g_return_val_if_fail (url != NULL, FALSE);
 
 	result = gnome_vfs_url_show_with_env (url, envp);
-	
+
 	switch (result) {
 	case GNOME_VFS_OK:
 		return TRUE;
-		
+
 	case GNOME_VFS_ERROR_INTERNAL:
 		g_set_error (error,
 		             GNOME_URL_ERROR,
 			     GNOME_URL_ERROR_VFS,
 			     _("Unknown internal error while displaying this location."));
 		break;
-		
+
 	case GNOME_VFS_ERROR_BAD_PARAMETERS:
 		g_set_error (error,
 			     GNOME_URL_ERROR,
 			     GNOME_URL_ERROR_URL,
 			     _("The specified location is invalid."));
 		break;
-	
+
 	case GNOME_VFS_ERROR_PARSE:
 		g_set_error (error,
 			     GNOME_URL_ERROR,
 			     GNOME_URL_ERROR_PARSE,
 			     _("There was an error parsing the default action command associated "
 			       "with this location."));
-		break;	
+		break;
 
 	case GNOME_VFS_ERROR_LAUNCH:
 		g_set_error (error,
@@ -105,15 +107,15 @@ gnome_url_show_with_env (const char  *url,
 			     GNOME_URL_ERROR_LAUNCH,
 			     _("There was an error launching the default action command associated "
 			       "with this location."));
-		break;	
-	
+		break;
+
 	case GNOME_VFS_ERROR_NO_DEFAULT:
 		g_set_error (error,
 			     GNOME_URL_ERROR,
 			     GNOME_URL_ERROR_NO_DEFAULT,
 			     _("There is no default action associated with this location."));
-		break;	
-	
+		break;
+
 	case GNOME_VFS_ERROR_NOT_SUPPORTED:
 		g_set_error (error,
 			     GNOME_URL_ERROR,
@@ -147,6 +149,13 @@ gnome_url_show_with_env (const char  *url,
 		}
 		break;
 
+	case GNOME_VFS_ERROR_INVALID_URI:
+		g_set_error (error,
+		             GNOME_URL_ERROR,
+			     GNOME_URL_ERROR_VFS,
+			     _("The location or file could not be found."));
+		break;
+
 	default:
 		g_set_error (error,
 			     GNOME_URL_ERROR,
